% Calculate Boiling Point and Return the Boiling point at the desired
% pressure. It initially defines an interval that the pressure acquired by
% the user lies on. Then, if pressure value is included at the file
% data.txt we notify the user about it and provide the corresponding value,
% otherwise it is provided the calculated pressure via interpolation

%INPUT ARGUMENTS:
% pressure: pressure value provided by the user to calculate the boiling
% point
% pSeries: the series of pressure values provided by the data.txt file
% bpSeries: the series of boiling point values provided by the data.txt file

%OUTPUT ARGUMENTS: 
% boilingPoint: calculated Boiling Point
% isExperimental: if true then this value is included at the data.txt file,
% otherwise it has been calculated via interpolation of two adjacent
% points.

function [ boilingPoint, isExperimental ] = calculateBoilingPoint( pressure, pSeries, bpSeries )

    % Find the interval that the desired pressure lies on
    [ boundDn, boundUp, bpDn, bpUp, isExperimental ] = findInterval(pressure, pSeries, bpSeries);
        
    % Calculate the Boiling Point
    if (isExperimental)
        
        if (pressure == boundUp)
            boilingPoint = bpUp;
        else
            boilingPoint = bpDn;
        end
        
    else
        boilingPoint = interpolation(boundDn, bpDn, boundUp, bpUp, pressure);
    end
    
end

