% Check experimental pressure values to find the interval that the given
% pressure is included. For that interval return the (P, BP) tuple, as well
% as the element index in the array and if this is an experimental value.

%INPUT ARGUMENTS:
% pressure: pressure value provided by the user to calculate the boiling
% point
% pSeries: the series of pressure values provided by the data.txt file
% bpSeries: the series of boiling point values provided by the data.txt file

%OUTPUT ARGUMENTS: 
% boundDn: pressure interval low bound
% boundUp: pressure interval upper bound
% bpDn: boiling point that corresponds to boundDn
% bpUp: boiling point that corresponds to boundUp
% isExperimental: if true then this value is included at the data.txt file,
% otherwise it has been calculated via interpolation of two adjacent
% points.

function [ boundDn, boundUp, bpDn, bpUp, isExperimental ] = findInterval( pressure, pSeries, bpSeries )

    boundDn = pSeries(1);
    boundUp = pSeries(length(pSeries));
    for i = 1 : length(pSeries) - 1
        if (pSeries(i) <= pressure) && (pressure <= pSeries(i + 1))
            boundDn = pSeries(i);
            boundUp = pSeries(i + 1);
            bpDn = bpSeries(i);
            bpUp = bpSeries(i + 1);            
            break;
        end
    end
    
    isExperimental = (boundDn == pressure) || (boundUp == pressure);    
end

