% Return the user acquired table pressure and boiling point series
% regarding the user defined interval (pMin, pMax) with step dp

%INPUT ARGUMENTS:
% pSeries: the series of pressure values provided by the data.txt file
% bpSeries: the series of boiling point values provided by the data.txt file
% pMin: user defined minimum table pressure value
% pMax: user defined maximum table pressure value
% dp: user defined step to report from minimum to maximum pressure values

%OUTPUT ARGUMENTS: 
% tblPSeries: the series of pressure values calculated
% tblBPSeries: the series of boiling point values calculated

function [tblPSeries, tblBPSeries] = fixTableData(pSeries, bpSeries, pMin, pMax, dp)
    tblPSeries = pMin:dp:pMax;
    tblPSeries = tblPSeries(:);    
    tblBPSeries = zeros(length(tblPSeries),1); %Preallocation
    for i = 1:length(tblPSeries)        
        [ boilingPoint, isExperimental ] = calculateBoilingPoint(tblPSeries(i), pSeries, bpSeries);
       tblBPSeries(i) = boilingPoint;
    end
end
